@@ -19,10 +19,11 @@ def register_models():
                 if model.__name__ not in exclude_models:
                     
                     if not model.exclude_model:
-                        
+                        print(model)
                         if model.all_cruds_types:
                             urlpatterns += model().build_generics_urls_crud()
                             urlpatterns += model().build_generics_urls_ajax_crud()
+                            print(urlpatterns)
                         
                         else:
                             
@@ -30,6 +31,8 @@ def register_models():
                                 urlpatterns += model().build_generics_urls_ajax_crud()
                             if model.normal_cruds:
                                 urlpatterns += model().build_generics_urls_crud()
+                            
+                            print(urlpatterns)
             except:
                 pass
     print(urlpatterns)
